@@ -21,6 +21,8 @@
 
 #include <private/qabstractwebview_p.h>
 
+#include <QtCore/qpointer.h>
+
 #if defined(Q_OS_IOS) && defined(__OBJC__)
 #include <UIKit/UIGestureRecognizer.h>
 
@@ -35,6 +37,7 @@
 
 Q_FORWARD_DECLARE_OBJC_CLASS(WKWebView);
 Q_FORWARD_DECLARE_OBJC_CLASS(WKNavigation);
+Q_FORWARD_DECLARE_OBJC_CLASS(WKWebViewConfiguration);
 
 #ifdef Q_OS_IOS
 Q_FORWARD_DECLARE_OBJC_CLASS(UIGestureRecognizer);
@@ -42,6 +45,29 @@ Q_FORWARD_DECLARE_OBJC_CLASS(UIGestureRecognizer);
 
 QT_BEGIN_NAMESPACE
 
+class QDarwinWebViewSettingsPrivate : public QAbstractWebViewSettings
+{
+    Q_OBJECT
+public:
+    explicit QDarwinWebViewSettingsPrivate(WKWebViewConfiguration *conf, QObject *p = nullptr);
+
+    bool localStorageEnabled() const;
+    bool javascriptEnabled() const;
+    bool localContentCanAccessFileUrls() const;
+    bool allowFileAccess() const;
+
+public Q_SLOTS:
+    void setLocalContentCanAccessFileUrls(bool enabled);
+    void setJavascriptEnabled(bool enabled);
+    void setLocalStorageEnabled(bool enabled);
+    void setAllowFileAccess(bool enabled);
+
+private:
+    WKWebViewConfiguration *m_conf = nullptr;
+    bool m_allowFileAccess = false;
+    bool m_localContentCanAccessFileUrls = false;
+};
+
 class QDarwinWebViewPrivate : public QAbstractWebView
 {
     Q_OBJECT
@@ -66,6 +92,7 @@ public:
     void setVisible(bool visible) override;
     void setFocus(bool focus) override;
     void updatePolish() override;
+    QAbstractWebViewSettings *getSettings() const override;
 
 public Q_SLOTS:
     void goBack() override;
@@ -84,6 +111,7 @@ protected:
 public:
     WKWebView *wkWebView;
     WKNavigation *wkNavigation;
+    QDarwinWebViewSettingsPrivate *m_settings = nullptr;
 #ifdef Q_OS_IOS
     UIGestureRecognizer *m_recognizer;
 #endif
